Crate cloud_terrastodon_azure_devops_types

Crate cloud_terrastodon_azure_devops_types 

Structs

AzureDevOpsAccountId
AzureDevOpsAgentPackage
AzureDevOpsAgentPackageVersion
AzureDevOpsAgentPool
AzureDevOpsAgentPoolCreatedBy
AzureDevOpsAgentPoolEntitlement
In Azure DevOps documentation, the grant for a given [AzureDevOpsProject] to use an [AzureDevOpsAgentPool] is called a “queue” but that’s silly so we will call it an entitlement instead. https://learn.microsoft.com/en-us/rest/api/azure/devops/distributedtask/queues/get?view=azure-devops-rest-7.1
AzureDevOpsAgentPoolEntitlementId
AzureDevOpsAgentPoolEntitlementPoolReference
AzureDevOpsAgentPoolId
AzureDevOpsAgentPoolName
A valid name is less than 128 characters in length and does not contain the following characters: ‘,’, ‘“’, ‘/’, ’', ‘[’, ‘]’, ‘:’, ‘|’, ‘<’, ‘>’, ‘+’, ‘=’, ‘;’, ‘?’, ‘*’.
AzureDevOpsAgentPoolOwner
AzureDevOpsEntraUserDescriptor
AzureDevOpsGroup
AzureDevOpsGroupLicenseEntitlement
AzureDevOpsGroupLicenseEntitlementGroupReference
AzureDevOpsGroupMember
AzureDevOpsLicenseEntitlementUserReference
AzureDevOpsLicenseRule
AzureDevOpsOrganizationName
https://learn.microsoft.com/en-us/azure/devops/organizations/settings/naming-restrictions?view=azure-devops#organization-names
AzureDevOpsOrganizationUrl
Represents an Azure DevOps organization URL, which can be in either the modern dev.azure.com format or the legacy visualstudio.com format. Does NOT contain a trailing slash when expanded.
AzureDevOpsProject
AzureDevOpsProjectId
AzureDevOpsProjectName
https://learn.microsoft.com/en-us/azure/devops/organizations/settings/naming-restrictions?view=azure-devops#project-names
AzureDevOpsRepo
AzureDevOpsRepoId
AzureDevOpsServiceEndpoint
AzureDevOpsServiceEndpointAuthorizationManagedServiceIdentity
AzureDevOpsServiceEndpointAuthorizationServicePrincipal
AzureDevOpsServiceEndpointAuthorizationUsernamePassword
AzureDevOpsServiceEndpointAuthorizationWorkloadIdentityFederation
AzureDevOpsServiceEndpointCreatedBy
AzureDevOpsServiceEndpointId
AzureDevOpsServiceEndpointName
AzureDevOpsServiceEndpointOperationStatus
AzureDevOpsServiceEndpointProjectReference
AzureDevOpsServiceEndpointProjectReferenceProjectReference
AzureDevOpsTeam
AzureDevOpsTeamId
AzureDevOpsTeamMember
AzureDevOpsTeamMemberIdentity
AzureDevOpsTestCasePointAssignment
AzureDevOpsTestCaseWorkItemReference
AzureDevOpsTestPlan
AzureDevOpsTestPlanIdentityRef
AzureDevOpsTestPlanReleaseEnvironmentDefinitionReference
AzureDevOpsTestPlanShallowReference
AzureDevOpsTestPlanTestOutcomeSettings
AzureDevOpsTestSuite
AzureDevOpsUserId
AzureDevOpsUserLicenseEntitlement
AzureDevOpsWorkItemQuery
Also known as: QueryHierarchyItem
AzureDevOpsWorkItemQueryFlattenedHierarchyEntry
AzureDevOpsWorkItemQueryId
ServiceEndpointAzureRMData
SuiteTestCase
WorkItemFieldReference
Reference to a field in a work item.
WorkItemLink
A link between two work items.
WorkItemQueryResult
The result of a work item query. https://learn.microsoft.com/en-us/rest/api/azure/devops/wit/wiql/query-by-id?view=azure-devops-rest-7.1 https://learn.microsoft.com/en-us/rest/api/azure/devops/wit/wiql/query-by-wiql?view=azure-devops-rest-7.1&tabs=HTTP#workitemqueryresult
WorkItemQuerySortColumn
A sort column.
WorkItemReference
Contains reference to a work item.

Enums

AzureDevOpsAgentPoolArgument
The name or identifier for an AzureDevOpsAgentPool
AzureDevOpsDescriptor
AzureDevOpsLicenseAssignmentSource
AzureDevOpsLicenseEntitlementOrigin
AzureDevOpsLicenseEntitlementStatus
AzureDevOpsLicenseRuleAssignmentSource
AzureDevOpsLicenseRuleGitHubLicenseType
AzureDevOpsLicenseRuleMsdnLicenseType
AzureDevOpsLicenseRuleSource
AzureDevOpsLicenseRuleStatus
AzureDevOpsLicenseType
AzureDevOpsProjectArgument
Project ID or name
AzureDevOpsProjectState
AzureDevOpsProjectVisibility
AzureDevOpsServiceEndpointAuthorization
AzureDevOpsServiceEndpointAuthorizationServicePrincipalAuthenticationType
AzureDevOpsServiceEndpointAzureRMDataCreationMode
AzureDevOpsServiceEndpointAzureRMDataEnvironment
AzureDevOpsServiceEndpointAzureRMDataIdentityType
AzureDevOpsServiceEndpointAzureRMDataScopeLevel
AzureDevOpsServiceEndpointData
AzureDevOpsServiceEndpointKind
AzureDevOpsServiceEndpointOperationStatusSeverity
AzureDevOpsServiceEndpointOperationStatusState
AzureDevOpsServiceEndpointOwner
AzureDevOpsUserArgument
LastAccessedDate
QueryResultType
The result type of a query.
QueryType
The type of query.

Constants

SUBSCRIPTION_ID_PREFIX